==> maemo-browser-mozilla-eal_0.1.0-2.tar.gz: maemo-browser-mozilla-eal-0.1.0/include/gtkmozilla.h <==
/**
  * Mozilla Web Engine Abstraction Layer.
  * @file gtkmozilla.h: GTK Mozilla Functions Declarations
  * @version $Rev: 2101 $
  * @date $LastChangedDate: 2005-11-02 09:35:49 -0400 (Wed, 02 Nov 2005) $
  *
  * Copyright (C) 2005 10LE
  * Copyright (C) 2005 Nokia Corporation.
  *
  * Contact: Leonid Zolotarev <leonid.zolotarev@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
  * as published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA
  *
  */

/* GTK Includes */
#include <gtk/gtk.h>

#ifndef __GTKMOZILLA_H__
#define __GTKMOZILLA_H__

/* Logging related includes */
#ifdef USE_OSSOLOG
#include <osso-log.h>
#endif

/* Some system functions */
#include <sys/stat.h>

/* Mozilla includes */
#include <gtkmozembed.h>
#include <gtkmozembed_internal.h>

#include "prenv.h"
#include "nsMemory.h"

/* Includes used by Find features */
#include "nsIWebBrowser.h"
#include "nsIWebBrowserFind.h"
#include "nsNetUtil.h"

/* Includes used by 'mozilla_preference_set|int|boolean */
#include "nsIPref.h"

#include "GulString.h"
#include "gmozillaengine.h"

/* Includes used by 'save_mozilla' */
#include "nsIPresShell.h"
#include "nsIDocShell.h"
#include "nsIDOMDocument.h"
#include "nsIDOMNodeList.h"
#include "nsIDOMHTMLImageElement.h"
#include "nsIDOM3Document.h"

#include "nsIDOMHTMLObjectElement.h"
#include "nsIDOMCSSPrimitiveValue.h"
#include "nsIDOMCSSStyleDeclaration.h"
#include "nsIDOMCSSValue.h"
#include "nsIDOMViewCSS.h"
#include "nsIDOMHTMLAnchorElement.h"
#include "nsIDOMHTMLAreaElement.h"
#include "nsIDOMHTMLInputElement.h"

#include "nsISelection.h"
#include "nsIWebBrowserPersist.h"
#include "nsIWebNavigation.h"
#include "nsIDocShellTreeItem.h"
#include "nsILocalFile.h"
#include "nsIDocShellTreeOwner.h"
#include "nsIDocument.h"

#include "nsVoidArray.h"
#include "nsIPresShell.h"
#include "nsIDOMStyleSheetList.h"
#include "nsIDOMStyleSheet.h"
#include "nsIClipboardCommands.h"
#include "nsIIOService.h"

#include "nsIContentViewer.h"
#include "nsIDOMKeyEvent.h"

#include "nsIWebBrowserFocus.h"
#include "nsIDocCharset.h"
#include "nsIMarkupDocumentViewer.h"

/* Included by Component Registering */
#include <nsDocShellCID.h>
#include <nsIGenericFactory.h>
#include <nsIComponentRegistrar.h>
#include <nsIServiceManager.h>

// Content handler component
#include "gmozillacontenthandler.h"

/* Includes used by context menus */
#include "nsIDOMMouseEvent.h"
#include "nsIDOMNSEvent.h"
#include "nsIDOMEventTarget.h"
#include "nsIDOMNSDocument.h"
#include "nsIDOMHTMLElement.h"
#include "nsIDOMNamedNodeMap.h"
#include "nsIDOMNSHTMLElement.h"

/* Testing zoomming - TONIKITOO */
#include "nsIZoomer.h"
#include "nsIDOMWindow.h"

/* Include used by cache */
#include <nsICacheService.h>

/* Includes used by the cookies */
#include "nsICookie.h"
#include "nsICookieManager.h"
#include "nsICookieService.h"

/* for profiles */
#include <nsProfileDirServiceProvider.h>

/* defines used by context menus */
#define CONTEXT_NONE     0
#define CONTEXT_DEFAULT  1
#define CONTEXT_LINK     2
#define CONTEXT_IMAGE    4
#define CONTEXT_DOCUMENT 8
#define CONTEXT_INPUT    64
#define CONTEXT_OTHER    128
#define CONTEXT_XUL      256
#define CONTEXT_MAIL	 512

#define PREF_ID NS_PREF_CONTRACTID

NS_GENERIC_FACTORY_CONSTRUCTOR(ContentHandler)

static const nsModuleComponentInfo sAppComps[] =
{
    // content handler component info
    {
        NS_IHELPERAPPLAUNCHERDLG_CLASSNAME,
        CONTENTHANDLER_CID,
        NS_IHELPERAPPLAUNCHERDLG_CONTRACTID,
        ContentHandlerConstructor
    }
};

typedef struct
{
    gchar *domain;
    gchar *name;
    gchar *value;
    gchar *path;
}
GMozillaCookieList;

#ifdef NS_TRACE_MALLOC
#include "nsTraceMalloc.h"
#endif

#ifdef MOZ_JPROF
#include "jprof.h"
#endif
/* Mozilla API Methods - make possible the direct comunitation between Minimo Browser and the "Gecko Render Engine" */

GtkWidget* gtk_mozilla_web_engine_new	();

GtkWidget* gtk_mozilla_web_engine_new_with_context (gpointer );

void gtk_mozilla_load_url 		(GtkWidget *, const gchar *);

void gtk_mozilla_go_back 		(GtkWidget *);

void gtk_mozilla_go_forward 		(GtkWidget *);

gboolean gtk_mozilla_can_go_back 	(GtkWidget *);

gboolean gtk_mozilla_can_go_forward 	(GtkWidget *);

void gtk_mozilla_stop_load 		(GtkWidget *);

void gtk_mozilla_reload 		(GtkWidget *);

gchar *gtk_mozilla_get_home_page 	(GtkWidget *);

gchar *gtk_mozilla_get_frame_title 	(GtkWidget *);

gboolean gtk_mozilla_preference_set 	(const char *, const char *);

gboolean gtk_mozilla_preference_set_boolean (const char *, gboolean );

gboolean gtk_mozilla_preference_set_int (const char *, gint  );

gboolean gtk_mozilla_preference_get_boolean (const char *, gboolean *);

gboolean gtk_mozilla_preference_get_int (const char *, gint *);

gboolean gtk_mozilla_preference_get (const char *, gchar **);

void gtk_mozilla_set_profile_path(const char *aDir, const char *aName);

void gtk_mozilla_set_zoom_scale (GtkWidget*, gint);
gint gtk_mozilla_get_zoom_scale (GtkWidget*);

PRUnichar * gtk_mozilla_engine_locale_to_unicode (const gchar *);

gboolean gtk_mozilla_find_text 		(GtkWidget *, const char *, PRBool , PRBool ,
                                  PRBool , PRBool);

gchar* latin1_to_utf8 			(const char *);

nsresult gtk_mozilla_select_all 	(GtkWidget *);

nsresult gtk_mozilla_cut	 	(GtkWidget *);

nsresult gtk_mozilla_copy		(GtkWidget *);

nsresult gtk_mozilla_paste 		(GtkWidget *);

PRBool gtk_mozilla_can_copy 		(GtkWidget * );

PRBool gtk_mozilla_can_paste 		(GtkWidget * );

PRBool gtk_mozilla_can_cut 		(GtkWidget * );

PRBool gtk_mozilla_can_selecttext 	(GtkWidget * );

gboolean mozilla_register_components 	(void);

gchar* gtk_mozilla_get_mime             (GtkWidget * );

gchar *gtk_mozilla_get_encoding 	(GtkWidget *);

nsresult gtk_mozilla_set_encoding 	(GtkWidget *, const gchar *);

gboolean gtk_mozilla_clear_cache        (gint );

gint gtk_mozilla_delete_all_cookies     (GSList *);

GSList* gtk_mozilla_get_cookie_list     (void );

glong gtk_mozilla_get_context_menu_type(GtkWidget *engine, gpointer event, GContextData * ctx_data);

nsresult gtk_mozilla_set_profile (const char *aDir, const char *aName);

/* This stuff was copypasted from gtkadi.sourceforge.net sources */

#ifdef GMOZ_DO_TRACE
	#ifdef USE_OSSOLOG
	#define GMOZ_TRACE(msg,...) ULOG_INFO("GMOZ: "msg,__VA_ARGS__);
	#define GMOZ_TRACE_MSG(msg) ULOG_INFO("GMOZ: "msg);
	#else
	#define GMOZ_TRACE(msg,...) g_printf("GMOZ: "msg"\n",__VA_ARGS__);
	#define GMOZ_TRACE_MSG(msg) g_printf("GMOZ: "msg"\n");
	#endif /* USE_OSSOLOG */
#else
	#define GMOZ_TRACE(msg,...)
	#define GMOZ_TRACE_MSG(msg)
#endif /* GMOZ_DO_TRACE */

#define GMOZ_LOG_NOT_IMP() GMOZ_TRACE("Not implemented: %s",__FUNCTION__)

#endif /* __GTKMOZILLA_H__ */

==> maemo-browser-mozilla-eal_0.1.1-1.tar.gz: maemo-browser-mozilla-eal-0.1.1/include/gtkmozilla.h <==
/**
  * Mozilla Web Engine Abstraction Layer.
  * @file gtkmozilla.h: GTK Mozilla Functions Declarations
  * @version $Rev: 2101 $
  * @date $LastChangedDate: 2005-11-02 09:35:49 -0400 (Wed, 02 Nov 2005) $
  *
  * Copyright (C) 2005 10LE
  * Copyright (C) 2005 Nokia Corporation.
  *
  * Contact: Leonid Zolotarev <leonid.zolotarev@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
  * as published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA
  *
  */

/* GTK Includes */
#include <gtk/gtk.h>

#ifndef __GTKMOZILLA_H__
#define __GTKMOZILLA_H__

/* Logging related includes */
#ifdef USE_OSSOLOG
#include <osso-log.h>
#endif

/* Some system functions */
#include <sys/stat.h>
#include <time.h>

/* Mozilla includes */
#include <gtkmozembed.h>
#include <gtkmozembed_internal.h>

#include "prenv.h"
#include "nsMemory.h"

/* Includes used by Find features */
#include "nsIWebBrowser.h"
#include "nsIWebBrowserFind.h"
#include "nsNetUtil.h"

/* Includes used by 'mozilla_preference_set|int|boolean */
#include "nsIPref.h"

#include "GulString.h"
#include "gmozillaengine.h"

/* Includes used by 'save_mozilla' */
#include "nsIPresShell.h"
#include "nsIDocShell.h"
#include "nsIDOMDocument.h"
#include "nsIDOMNodeList.h"
#include "nsIDOMHTMLImageElement.h"
#include "nsIDOM3Document.h"

#include "nsIDOMHTMLObjectElement.h"
#include "nsIDOMCSSPrimitiveValue.h"
#include "nsIDOMCSSStyleDeclaration.h"
#include "nsIDOMCSSValue.h"
#include "nsIDOMViewCSS.h"
#include "nsIDOMHTMLAnchorElement.h"
#include "nsIDOMHTMLAreaElement.h"
#include "nsIDOMHTMLInputElement.h"

#include "nsISelection.h"
#include "nsIWebBrowserPersist.h"
#include "nsIWebNavigation.h"
#include "nsIDocShellTreeItem.h"
#include "nsILocalFile.h"
#include "nsIDocShellTreeOwner.h"
#include "nsIDocument.h"

#include "nsVoidArray.h"
#include "nsIPresShell.h"
#include "nsIDOMStyleSheetList.h"
#include "nsIDOMStyleSheet.h"
#include "nsIClipboardCommands.h"
#include "nsIIOService.h"

#include "nsIContentViewer.h"
#include "nsIDOMKeyEvent.h"

#include "nsIWebBrowserFocus.h"
#include "nsIDocCharset.h"
#include "nsIMarkupDocumentViewer.h"

/* Included by Component Registering */
#include <nsDocShellCID.h>
#include <nsIGenericFactory.h>
#include <nsIComponentRegistrar.h>
#include <nsIServiceManager.h>

// Content handler component
#include "gmozillacontenthandler.h"

// Prompt service
#include "gmozillapromptservice.h"

/* Includes used by context menus */
#include "nsIDOMMouseEvent.h"
#include "nsIDOMNSEvent.h"
#include "nsIDOMEventTarget.h"
#include "nsIDOMNSDocument.h"
#include "nsIDOMHTMLElement.h"
#include "nsIDOMNamedNodeMap.h"
#include "nsIDOMNSHTMLElement.h"

/* Testing zoomming - TONIKITOO */
//#include "nsIZoomer.h"
#include "nsIDOMWindow.h"
#include "imgIRequest.h"
#include "imgIContainer.h"
#include "nsIImageLoadingContent.h"

/* Include used by cache */
#include <nsICacheService.h>

/* Includes used by the cookies */
#include "nsICookie.h"
#include "nsICookieManager.h"
#include "nsICookieService.h"

/* for profiles */
#include <nsProfileDirServiceProvider.h>

/* defines used by context menus */
#define CONTEXT_NONE     0
#define CONTEXT_DEFAULT  1
#define CONTEXT_LINK     2
#define CONTEXT_IMAGE    4
#define CONTEXT_DOCUMENT 8
#define CONTEXT_INPUT    64
#define CONTEXT_OTHER    128
#define CONTEXT_XUL      256
#define CONTEXT_MAIL	 512

#define PREF_ID NS_PREF_CONTRACTID

NS_GENERIC_FACTORY_CONSTRUCTOR(ContentHandler)
NS_GENERIC_FACTORY_CONSTRUCTOR(PromptService)

static const nsModuleComponentInfo sAppComps[] =
{
    // content handler component info
    {
        NS_IHELPERAPPLAUNCHERDLG_CLASSNAME,
        CONTENTHANDLER_CID,
        NS_IHELPERAPPLAUNCHERDLG_CONTRACTID,
        ContentHandlerConstructor
    },
    // prompt service
    {
        "Prompt Service",
        NS_PROMPTSERVICE_CID,
        NS_PROMPTLAUNCHERDLG_CONTRACTID,
        PromptServiceConstructor
    }
};

typedef struct
{
    gchar *domain;
    gchar *name;
    gchar *value;
    gchar *path;
}
GMozillaCookieList;

#ifdef NS_TRACE_MALLOC
#include "nsTraceMalloc.h"
#endif

#ifdef MOZ_JPROF
#include "jprof.h"
#endif
/* Mozilla API Methods - make possible the direct comunitation between Minimo Browser and the "Gecko Render Engine" */

GtkWidget* gtk_mozilla_web_engine_new	();

GtkWidget* gtk_mozilla_web_engine_new_with_context (gpointer );

void gtk_mozilla_load_url 		(GtkWidget *, const gchar *);

void gtk_mozilla_go_back 		(GtkWidget *);

void gtk_mozilla_go_forward 		(GtkWidget *);

gboolean gtk_mozilla_can_go_back 	(GtkWidget *);

gboolean gtk_mozilla_can_go_forward 	(GtkWidget *);

void gtk_mozilla_stop_load 		(GtkWidget *);

void gtk_mozilla_reload 		(GtkWidget *);

gchar *gtk_mozilla_get_home_page 	(GtkWidget *);

gchar *gtk_mozilla_get_frame_title 	(GtkWidget *);

gboolean gtk_mozilla_preference_set 	(const char *, const char *);

gboolean gtk_mozilla_preference_set_boolean (const char *, gboolean );

gboolean gtk_mozilla_preference_set_int (const char *, gint  );

gboolean gtk_mozilla_preference_get_boolean (const char *, gboolean *);

gboolean gtk_mozilla_preference_get_int (const char *, gint *);

gboolean gtk_mozilla_preference_get (const char *, gchar **);

PRBool gtk_mozilla_set_profile_path (const char *, const char *);

void gtk_mozilla_set_zoom_scale (GtkWidget*, gint);
gint gtk_mozilla_get_zoom_scale (GtkWidget*);

PRUnichar * gtk_mozilla_engine_locale_to_unicode (const gchar *);

gboolean gtk_mozilla_find_text 		(GtkWidget *, const char *, PRBool , PRBool , PRBool , PRBool);

nsresult gtk_mozilla_select_all 	(GtkWidget *);

nsresult gtk_mozilla_cut	 	(GtkWidget *);

nsresult gtk_mozilla_copy		(GtkWidget *);

nsresult gtk_mozilla_paste 		(GtkWidget *);

PRBool gtk_mozilla_can_copy 		(GtkWidget * );

PRBool gtk_mozilla_can_paste 		(GtkWidget * );

PRBool gtk_mozilla_can_cut 		(GtkWidget * );

PRBool gtk_mozilla_can_selecttext 	(GtkWidget * );

gboolean mozilla_register_components 	(void);

gchar* gtk_mozilla_get_mime             (GtkWidget * );

gchar *gtk_mozilla_get_encoding 	(GtkWidget *);

nsresult gtk_mozilla_set_encoding 	(GtkWidget *, const gchar *);

gboolean gtk_mozilla_clear_cache        (gint );

gint gtk_mozilla_delete_all_cookies     (GSList *);

GSList* gtk_mozilla_get_cookie_list     (void );

glong gtk_mozilla_get_context_menu_type(GtkWidget *, gpointer , GContextData * );

nsresult gtk_mozilla_get_content_viewer (GtkWidget *, nsIContentViewer **);

/* This stuff was copypasted from gtkadi.sourceforge.net sources */

#ifdef GMOZ_DO_TRACE
	#ifdef USE_OSSOLOG
	#define GMOZ_TRACE(msg,...) ULOG_INFO("GMOZ: "msg,__VA_ARGS__);
	#define GMOZ_TRACE_MSG(msg) ULOG_INFO("GMOZ: "msg);
	#else
	#define GMOZ_TRACE(msg,...) g_printf("GMOZ: "msg"\n",__VA_ARGS__);
	#define GMOZ_TRACE_MSG(msg) g_printf("GMOZ: "msg"\n");
	#endif /* USE_OSSOLOG */
#else
	#define GMOZ_TRACE(msg,...)
	#define GMOZ_TRACE_MSG(msg)
#endif /* GMOZ_DO_TRACE */

#define GMOZ_LOG_NOT_IMP() GMOZ_TRACE("Not implemented: %s",__FUNCTION__)

#endif /* __GTKMOZILLA_H__ */
